---
title: "Drivers of inequality Vietnam"
author:
    - Marty Oehme
papersize: A4
geometry:
  - left=2cm
  - right=2.5cm
  - top=2.5cm
  - bottom=2.5cm
indent: true
linestretch: 1.25
fontfamily: lmodern
fontsize: 12
lang: en
bibliography: /home/marty/projects/jobs/afd/input/libraries/afd-dev-research.bib
csl: /home/marty/documents/library/academia/styles/APA-7.csl
output:
    pdf_document:
        latex_engine: xelatex
header-includes:
    - \usepackage{fvextra}
    - \DefineVerbatimEnvironment{Highlighting}{Verbatim}{breaklines,breakanywhere,commandchars=\\\{\}}
---

<!-- ## Script Issues
* Too wordy: on within-sector/between-sector rural dimensions; on non-quantitative environmental dimensions
* Too vague on 2 lowest quintile effects, especially as expressed through Gini impacts
* Wordings do not quite capture quintile poverty assessments for coming descriptive statistics
-->

## Script

Summary:

-----
* Economic restructuring and trade liberalization further drives economy towards wage work, service work the manufacturing sectors.
* Structural changes drove poverty down in absolute terms, but leave those in vulnerable positions consistently at-risk of slipping into or worsening existing poverty.
* Economic inequality in Vietnam intersectional between ethnic minorities, rural populations, regional and gendered dimensions.
* Ethnic minorities increase in economic inequality, driven by worse returns on assets (human capital and land) and worse access to endowments (land and educational infrastructure).
* Environmental degradation and environmental shocks consistently worsen within-sector inequalities for ethnic minority and female population.
* Vietnam in vulnerable position to increasing exogenous shocks due to climate change, building capacity against which may require focus shift on risk management and preventative measures
-----

Vietnam's economy is now firmly in the third decade of ongoing economic reform (*Doi Moi*) as a market-based economy,
which lead to remarkable growth phases through opening the economy to international trade while,
seen over the bulk of its population, attempting to keep inequality rates managed through policies of controlling credit and reducing subsidies to state-owned enterprises [@Bui2019].

<!-- poor/poverty <40%; mention low social mobility: different social insurances [@Bui2019] -->
Poverty in Vietnam is marked by a drastic reduction in absolute terms over this time with some of the decline directly attributable to the liberalization of markets over the country's growth more generally [@WorldBank2012; @McCaig2011; @Le2022].
While the rate of decline slowed since the mid-2000s [@VASS2006; @VASS2011],
it continued declining in tandem with small income inequality decreases.
The overall income inequality decrease that Vietnam experienced from the early 2000s suggests that its growth has been accompanied by equity extending beyond poverty reduction [@Benjamin2017].
On the other hand, Le et al. [-@Le2021] suggest a slight increase in overall income distribution from 2010-2018.
At the same time, the ones most affected by poverty through welfare inequalities stay unaltered, as do largely the primary factors accompanying it:
There is severe persistent poverty among ethnic minorities in Vietnam [@Baulch2012],
concomitant with low education and skills, more prevalent dependency on subsistence agriculture, physical and social isolation, specific disadvantages which become linked to ethnic identities and a greater exposure to natural disasters and risks [@Kozel2014].
Economic inequality and poverty in Vietnam thus underlies an intersectional focus, between ethnic minorities, regional situations, rural-urban divides and gendered lines,
one which exogenous shocks can rapidly exacerbate as the example of the COVID-19 pandemic has recently shown [@Ebrahim2021].

* estimated Gini coeff, overall income distribution: [@Le2021]
    * fluctuating 0.42-0.44 (2010-2018)
    * highest in Central highlands (2016)
    * absolute income inequality may be rising, top quintile 9.2 times income lowest quintile (2010) to 9.8 times (2016) (Hung 2019)

<!-- rural inequality -->
In the 1990s, as the initial stages of the Doi Moi reform bore fruit with economic growth,
the first amplifications of inequalities along new rural-urban boundaries became equally visible.
There are two complementary views on the primary dimensions of rural inequalities.
On the one hand, the urban-rural divide may be driven by structural effects:
the welfare returns to education and agricultural activities changed dramatically from,
and with it the requirements on policy adaptations required for stemming inequality.
Nguyen et al. [-@Nguyen2007] argue this for the period of 1993-1998, with their findings that income returns to education improved dramatically over this time and arguing through this that suggested development policies had a strictly urban bias ---
on the whole they would benefit both from better education and vastly benefit from the restructuring of Vietnam's economy.
This view was in turn confirmed when Theil Index decomposition found within-sector inequality remaining largely stable while between-sector inequality rose significantly [@Fesselmeyer2010].
On the other, Thu Le and Booth [-@ThuLe2014] argue that the urban-rural inequality continued to increase over the years due to both covariate effects and the returns to those covariate effects, primarily education age structures and labor market activities, but also geographic location.

The gap between urban and rural sectors grew, a gap which would continue to widen until 2002, when within-sector rural inequalities started to become more important for inequalities than those between the sectors [@Fritzen2005; @ThuLe2014].
In the time of within-sector inequality becoming more pronounced many studies, while important contributions to continued inequality research, had a tendency to mask those inequalities in favor of continued analysis of between-sector trends ---
often to the detriment of the high degree of heterogeneity depending on geographic characteristics such as remoteness or cultural factors, as Cao and Akita [-@Cao2008] note.
In a recent study, Bui and Imai [-@Bui2019] build on the insights of these viewpoints and also find access to basic education the linchpin of improving rural welfare while its lack combined with economic restructuring precluded many from equal opportunities toward human capital improvement.
They found that, as within-sector became more pronounced again after 2010,
the large proportion of uneducated heads of households in rural sectors and low social mobility of rural poor combine to increase within-sector inequality while the economy overall changing toward salaried work compounded within-rural and urban-rural disparities.
Early income studies generally highlighted the important role of agricultural incomes in reducing, or at the very not exacerbating, income inequality [@Benjamin2004].
Benjamin et al. [-@Benjamin2017] expand on this over a longer time-frame by decomposing different household income sources underlying Vietnam's structural economic changes.
They find that, while there is an overall decrease in income inequality throughout Vietnam between 2002 and 2014 and the urban-rural divide also continued its downward trend,
rural inequality indeed increased over this time.
Wage income and family business income were the main drivers of overall inequality in 2002 (accounting for over 30% of income but 60% of inequality) and remittances add a small share on top,
which, while decreased in effect (risen to 42% of total income),
remain majorly correlated with income distributions and thus income inequality.
Thus, while the study points to both more prevalent and equally distributed labor markets and wage labor opportunities,
these effects apply to the overall population and not just within-rural inequalities which are driven in large part by ethnicity, education and environmental factors.

* estimated Gini coeff, rural and urban expenditure: [@Bui2019]
    * 0.36-0.39 (2008-2010), 0.36 (2012)
    * Theil rural-urban between: 0.22-0.19 (2008-2012)
    * Theil rural-rural within: 0.74-0.83 (2008-2012)

<!-- ethnicity inequality -->
Ethnic minorities in Vietnam are distinctly over-represented in poverty in addition to often being left behind in the development process, not least due to being extreme representatives of the economic situation of Vietnam's rural population.
Ethnic minority households have a tenuous economic position - and it is deteriorating.
In earlier studies on ethnic inequalities in Vietnam, a strong welfare gap between ethnic minorities and the majority was already visible.
Van de Walle [-@vandeWalle2001] already views the situation of ethnic minorities inhabiting predominantly remote rural areas with lower living standards than the ethnic majority,
a finding they suggest created due to environmental and structural differences (difficult terrain, poor infrastructure, less access to off-farm work and the market economy and inferior access to education) and compounded by social immobility and social isolation.
Baulch et al. [-@Baulch2012] find that between 1993 and 2004, the welfare gap between the two groups had increased by 14.6%, two-fifths of which were due to endowments such as demographic structure and education while geographic variables make up less than one-fifth.
They additionally suggest some drivers of the inequality being the lack of ability speaking the Vietnamese language or the distance to a commune or district center amplifying isolating effects, though a large part of the change was linked to temporal changes of unobservable factors -
which the study conjectures to be due to negative ethnic stereotyping, a poor understanding of ethnic customs and culture and further (unobserved) variations in household-level endowments.
While in 2002 the ethnic minority population living in rural areas was below 15%, it rose to over 18% in 2014 - both due to higher fertility among minorities and ethnic majority Kinh urbanizing at a higher rate - and the ratio of Kinh to minority incomes rose to more than 2.0 in 2014 [@Benjamin2017].
The same study finds that income inequality rose even more sharply *within* ethnic minorities, while that of rural Kinh, though increasing from 2002 to 2014, fell back to 2002 levels around 2014.
These findings suggest that the primary drivers of rural income inequality are a growing gap between Kinh and minorities while at the same time a similar rising inequality develops among minority rural populations themselves.
<!-- TODO Find levels of population rural/urban in other sources -->
In the same vein as the urban-rural divide, Nguyen et al. [-@Nguyen2007] thus argue for structural policy failures which essentially lowered the returns on ethnicity along sectorial dividing lines of education and primary income types.

* estimated Gini coeff: rural ethnicities [@Baulch2012]
    * per capita HH expenditure between Kinh and Hoa majority 0.27 (1993, 2004)
    * per capita HH expenditure within minority groups 0.24 (1993), 0.29 (2004) sg increase

<!-- environmental inequality -->
While the effect of agriculture on inequality outcomes is an equalizing one,
its future growth, and that of agricultural livelihoods, is threatened by vulnerability to risks such as natural disasters and environmental degradation, exacerbated through climate change [@Kozel2014].
Kozel [-@Kozel2014] goes on to argue the continuous precarity of poor households against economy-wide shocks (such as the effect of climate change on rainfall and temperatures) but also highlights the danger of vulnerable households *falling* into poverty through generated inequalities.
Looking at the particularities of flood risk management in the Ninh Binh province, Mottet and Roche [-@Mottet2009] find that most areas within the region are vulnerable.
They find the strengths of current management lying in prevention with existing dykes designed to channel high waters, effective monitoring of weather conditions (rainfall or typhoons) and consolidation or elevation of existing residences, while the weaknesses are mainly centered around insufficient information given to inhabitants over flood risks, few compensation systems for flood victims and construction policies continuing to allow building in flood-endangered zones.
Sen et al. [-@Sen2021] estimate that the main barriers to better information are farmers' lack of trust toward formal climate-related services, their lack of perceived risk from climate change itself and difficulties in balancing both climate adaptation and economic benefits of interventions.
They argue that, while ethnicity itself is not a barrier to information access with all farmers receiving information through informal channels ---
friends neighbors and market actors instead of agricultural departments or mass media ---
cultural issues such as language do come into play and act as a barrier.
Reactionary economic mitigation efforts by households, such as reduced healthcare spending, selling of land or livestock assets, taking children out of school due to needing assistance at home can in turn lead to longer-term adverse consequences (thus, *mal-adaptation*) [@Kozel2014].

* estimated Gini coeff: Ninh Binh province [@Kozel2014]
    * 0.283 (2013)
    * top 90th percentile 3.57 times income 10th percentile
    * 13.63 percent in richest quintile

<!-- extreme events / climate change -->
The results are further intensification of inequality along existing social lines during extreme events such as flooding:
The effects of inequalities mainly affecting ethnic minorities are illustrated by Son and Kingsbury [-@Son2020],
with droughts impacting yield losses between 50% and 100%, cold snaps leading to loss of livestock and floods damaging residential structures but even more importantly disrupting livelihoods through landslides, crop destruction and overflowing fish ponds.
Locally employed coping strategies, they argue, are always conditional on the strength and foresight of institutions and implemented preventative policies along local but also regional and central levels.
Similarly, Ylipaa et al. [-@Ylipaa2019] analyze impacts mainly across the gender dimension to find that,
resulting inequalities may be exacerbated with differentiated rights and responsibilities leading to unequal opportunities and, especially, decreased female mobility in turn increasing their vulnerability to climate impacts with a reduced capacity to adapt.
Hudson et al. [-@Hudson2021] along the same dimension find that,
while the set of relevant variables is largely similar with age, social capital, internal and external support after the flood and the perceived severity of previous flood impacts having major impacts,
women tend to show longer recovery times and psychological variables can influence recovery rates more than some adverse flood impacts.

While the quantitative evidence for impacts of such shock events are relatively sparse, Jafino et al. [-@Jafino2021] lament the overuse of aggregate perspectives, instead disaggregating the local and inter-sectoral effects to find out that flood protection efforts in the Mekong Delta often predominantly support large-scale farming while small-scale farmers can be harmed through them.
They find that measures decrease the aggregate total output and equity indicators by disaggregating profitability indicators into inundation, sedimentation, soil fertility, nutrient dynamics, behavioral land-use in an assessment which sees within-sector policy responses often having an effect on adjacent sectors, increasing the inter-district Gini coefficient.
Adaptation during these catastrophic events reinforces the asset and endowment drivers of non-shock event times,
with impacts levels often depending on access to non-farm income sources, access to further arable land, knowledge of adaptive farming practices and mitigation of possible health risks such as water contamination [@Son2020].
Karpouzoglou et al. [-@Karpouzoglou2019] make the point that, ultimately, the pure coupling of flood resilience into infrastructural or institutional interventions needs to take care not to amplify existing inequalities through unforeseen consequences ('ripple effects') which can't be escaped by vulnerable people due to their existing immobility.

<!-- conclusion -->
Inequality in Vietnam, then, is slowly rising across the whole population distribution,
runs the danger of increasing due to schisms opening within individual sectors of vulnerable groups.
Rural populations experience a trend towards increasing inequality within their sector,
driven primarily by the social exclusion and geographic isolation of ethnic minorities,
its most precarious population.
Ethnic minorities' inequality is slowly increasing due to receiving worse returns to their existing assets (especially human capital and land) and generally worse access to endowments in the first place (land and educational infrastructure).
The restructuring of the economy, turning the labor force toward urban areas and within them wage work in manufacturing and service industries,
leaves behind immobile rural populations whose ability to be employed for non-farm shrink further.
All these factors are at risk of experiencing large negative shocks as climate change exacerbates existing extreme environmental conditions,
which in turn threaten to increase economic inequalities for both the rural population at large, ethnic minorities and women especially.
Women in rural areas experience worse mobility and fewer economic opportunities and are thus less able to adapt to environmental degradation.
While inequality as an aggregate is kept relatively low Vietnam's growth rate,
both ethnic minorities and the rural female population are thus at risk of being left behind economically.

\pagebreak
## References
